@@ -8,19 +8,13 @@
 #include <phonon/MediaObject>
 #include <phonon/MediaSource>
 
-//#include "flite.h"
-
-
-
 Audio::Audio(QObject *parent) :
     QObject(parent)
 {
 
 
 }
-/*extern "C" {
-    cst_voice* register_cmu_us_kal();
-}*/
+
 void Audio::createWav(QString filename)
 {
 
@@ -36,7 +30,7 @@ void Audio::createWav(QString filename)
         QString program = "flite"; //espeak
         QStringList arguments;
 
-        arguments << "-f" << filename << "-o" << audio; //arguments << "-f" << filename << "-s" << "110" << "-v " << "en/en-rp" << -w << audio;
+        arguments << "-voice" << "awb" << "-f" << filename << "-o" << audio; //arguments << "-f" << filename << "-s" << "110" << "-v " << "en/en-rp" << -w << audio;
         qDebug()<<arguments;
         QProcess *myProcess = new QProcess();
 
@@ -49,14 +43,6 @@ void Audio::createWav(QString filename)
                                       Phonon::MediaSource(audioFile->fileName()));
 
 
-   /*         flite_init();
-            cst_voice *v;
-            v = register_cmu_us_kal();
-            cst_wave *audioWav;
-            audioWav = flite_text_to_wave("hello", v);
-            //audioFile = flite_text_to_wave("hello", v);*/
-
-
         connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
 
         audioFile->close();
