@@ -23,9 +23,12 @@ private slots:
 
     void on_clearButton_clicked();
 
+    void on_removePlaylists_clicked();
+
 signals:
     void closeButtonClicked();
     void clearCurrentClicked();
+    void removePlaylistsButtonClicked();
 
 private:
     Ui::Options *ui;
