@@ -96,7 +96,7 @@ void Player::on_backwardButton_clicked()
 
 void Player::on_forwardButton_clicked()
 {
-    if (this->ui->playListWidget->currentRow() < ui->playListWidget->count())
+    if (this->ui->playListWidget->currentRow() < this->ui->playListWidget->count())
     {
         reload = true;
         this->ui->playListWidget->item(this->ui->playListWidget->currentRow())->setSelected(false);
