@@ -1,6 +1,11 @@
 #include "playlist.h"
 #include "ui_playlist.h"
 #include <QMap>
+#define NORMAL "normal"
+#define REMOVE "remove"
+#ifdef Q_WS_MAEMO5
+#include <QtMaemo5/QMaemo5InformationBox>
+#endif
 
 Playlist::Playlist(QWidget *parent) :
     QWidget(parent),
@@ -10,6 +15,7 @@ Playlist::Playlist(QWidget *parent) :
     playlistlist = new Playlists();
     this->updateList();
     ui->treeWidget->setColumnCount(1);
+    mode = NORMAL;
 
 
 
@@ -22,13 +28,27 @@ Playlist::~Playlist()
 
 void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
 {
-    if (item->childCount() == 0)
-        this->articleSelected(item, column);
+    if (mode == NORMAL)
+    {
+        if (item->childCount() == 0)
+            this->articleSelected(item, column);
 
-    else
-        this->playlistSelected(item->takeChildren(), column);
+        else
+            this->playlistSelected(item->takeChildren(), column);
 
-    this->hide();
+        this->hide();
+    }
+    if (mode == REMOVE)
+    {
+        if (item->childCount() == 0)
+            playlistlist->removePlaylistItem(item, column, item->parent());
+
+        else
+            playlistlist->removePlaylist(item->text(column));
+
+        this->updateList();
+       // this->hide();
+    }
 }
 
 QStringList Playlist::getPlaylists()
@@ -60,3 +80,12 @@ void Playlist::updateList()
     this->ui->treeWidget->insertTopLevelItems(0, items);
 }
 
+void Playlist::setMode(QString mode)
+{
+    this->mode = mode;
+    #ifdef Q_WS_MAEMO5
+    QMaemo5InformationBox::information(this, "Remove playlists or playlist items by clicking on them",
+                                                QMaemo5InformationBox::DefaultTimeout);
+    #endif
+}
+
