@@ -3,6 +3,7 @@
 #include <QMap>
 #include <QStringList>
 #include <QFile>
+#include <QTreeWidgetItem>
 
 class Playlists : public QObject
 {
@@ -12,6 +13,8 @@ public:
     QMap<QString, QStringList> getPlaylists();
     QStringList getPlaylistContent(QString title);
     void addNewItemToPlaylist(QString title, QString item);
+    void removePlaylist(QString title);
+    void removePlaylistItem(QTreeWidgetItem *item, int column, QTreeWidgetItem *parent);
 
 private:
     QMap<QString, QStringList> playlists;
